ChunkedPlateCarreeSampler
=========================

.. currentmodule:: toasty.samplers

.. autoclass:: ChunkedPlateCarreeSampler
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ChunkedPlateCarreeSampler.n_chunks

   .. rubric:: Methods Summary

   .. autosummary::

      ~ChunkedPlateCarreeSampler.filter
      ~ChunkedPlateCarreeSampler.sampler

   .. rubric:: Attributes Documentation

   .. autoattribute:: n_chunks

   .. rubric:: Methods Documentation

   .. automethod:: filter
   .. automethod:: sampler
